==> ros-rolling-fastrtps_2.10.1.orig.tar.gz: ros-rolling-fastrtps-2.10.1/RELEASE_SUPPORT.md <==
# Release support

Please, refer to the [master branch](https://github.com/eProsima/Fast-DDS/blob/master/RELEASE_SUPPORT.md) for the latest version of this document.

*eProsima Fast DDS* maintains several releases with different support cycles.
Major releases are scarce and they are made when public API is broken (more information about *eProsima Fast DDS* versioning can be found [here](https://github.com/eProsima/Fast-DDS/blob/master/VERSIONING.md)).
Latest major release is v2.0.0 (June 2020), which introduced the DDS compliant API.

Each quarter, a new Fast DDS minor version with new features is released.
By default, *eProsima Fast DDS* minor releases have a lifecycle of **6 months**.
However, the life of certain branches can be extended depending on costumer and user needs.
Within the support period of any minor version, there may be several patch releases that either add new functionalities in an ABI compatible way or fix possible issues.
Before the minor release end of life (EOL) date, a final patch release including the latest fixes will be made available if there are any changes not included in any previous patch release of the same minor version.

The table below outlines the *eProsima Fast DDS* minor releases and their support cycles:

|Version branch|Release Date|EOL Date|
|--------------|------------|--------|
|***v2.10.x***|***March 2023***|***May 2024 [^*]***|
|***v2.9.x***|***December 2022***|***June 2023***|
|***v2.8.x***|***September 2022***|***March 2023***|
|v2.7.x|July 2022|January 2023|
|***v2.6.x***|***March 2022***|***May 2023 [^*]***|
|v2.5.x|December 2021|June 2022|
|v2.4.x|September 2021|March 2022|
|v2.3.x|March 2021|November 2022|
|v2.2.x|January 2021|February 2022|
|***v2.1.x***|***November 2020***|***May 2023***|
|v2.0.x|June 2020|February 2022|
|v1.10.x|April 2020|February 2022|
|v1.9.x|August 2019|February 2022|
|v1.8.x|May 2019|February 2022|
|v1.7.x|December 2018|February 2022|

[^*]: Support may be extended.

==> ros-rolling-fastrtps_2.13.2.orig.tar.gz: ros-rolling-fastrtps-2.13.2/RELEASE_SUPPORT.md <==
# Release support

Please, refer to the [master branch](https://github.com/eProsima/Fast-DDS/blob/master/RELEASE_SUPPORT.md) for the latest version of this document.

*eProsima Fast DDS* maintains several releases with different support cycles.
Major releases are scarce and they are made when public API is broken (more information about *eProsima Fast DDS* versioning can be found [here](https://github.com/eProsima/Fast-DDS/blob/master/VERSIONING.md)).
Latest major release is v2.0.0 (June 2020), which introduced the DDS compliant API.

Each quarter, a new Fast DDS minor version with new features is released.
By default, *eProsima Fast DDS* minor releases have a lifecycle of **6 months**.
However, the life of certain branches can be extended depending on costumer and user needs.
Within the support period of any minor version, there may be several patch releases that either add new functionalities in an ABI compatible way or fix possible issues.
Before the minor release end of life (EOL) date, a final patch release including the latest fixes will be made available if there are any changes not included in any previous patch release of the same minor version.

The table below outlines the *eProsima Fast DDS* minor releases and their support cycles:

|Version branch|Release Date|EOL Date|
|--------------|------------|--------|
|***v2.13.x***|***December 2023***|***June 2024***|
|***v2.12.x***|***September 2023***|***March 2024***|
|***v2.11.x***|***July 2023***|***January 2024***|
|***v2.10.x (LTS)***|***March 2023***|***May 2024 [^*]***|
|v2.9.x|December 2022|July 2023|
|v2.8.x|September 2022|March 2023|
|v2.7.x|July 2022|January 2023|
|***v2.6.x (LTS)***|***March 2022***|***May 2024 [^*]***|
|v2.5.x|December 2021|June 2022|
|v2.4.x|September 2021|March 2022|
|v2.3.x|March 2021|November 2022|
|v2.2.x|January 2021|February 2022|
|v2.1.x|November 2020|May 2023|
|v2.0.x|June 2020|February 2022|
|v1.10.x|April 2020|February 2022|
|v1.9.x|August 2019|February 2022|
|v1.8.x|May 2019|February 2022|
|v1.7.x|December 2018|February 2022|

[^*]: Support may be extended.
